@@ -3,19 +3,19 @@ module Sound.OSC.Packet where
 
 import Data.List {- base -}
 
-import Sound.OSC.Datum {- hosc3 -}
-import Sound.OSC.Time {- hosc3 -}
+import Sound.OSC.Datum {- hosc -}
+import Sound.OSC.Time {- hosc -}
 
 -- * Message
 
 -- | OSC address pattern.  This is strictly an ASCII value, however it
 --   is very common to pattern match on addresses and matching on
---   'C.ByteString' requires @OverloadedStrings@.
+--   Data.ByteString.Char8 requires @OverloadedStrings@.
 type Address_Pattern = String
 
 -- | An OSC message, an 'Address_Pattern' and a sequence of 'Datum'.
-data Message = Message {messageAddress :: Address_Pattern
-                       ,messageDatum :: [Datum]}
+data Message = Message {messageAddress :: !Address_Pattern
+                       ,messageDatum :: ![Datum]}
                deriving (Eq,Read,Show)
 
 -- | 'Message' constructor.  It is an 'error' if the 'Address_Pattern'
@@ -29,8 +29,8 @@ message a xs =
 -- * Bundle
 
 -- | An OSC bundle, a 'Time' and a sequence of 'Message's.
-data Bundle = Bundle {bundleTime :: Time
-                     ,bundleMessages :: [Message]}
+data Bundle = Bundle {bundleTime :: !Time
+                     ,bundleMessages :: ![Message]}
               deriving (Eq,Read,Show)
 
 -- | OSC 'Bundle's can be ordered (time ascending).
@@ -48,8 +48,8 @@ bundle t xs =
 -- * Packet
 
 -- | An OSC 'Packet' is either a 'Message' or a 'Bundle'.
-data Packet = Packet_Message {packetMessage :: Message}
-            | Packet_Bundle {packetBundle :: Bundle}
+data Packet = Packet_Message {packetMessage :: !Message}
+            | Packet_Bundle {packetBundle :: !Bundle}
               deriving (Eq,Read,Show)
 
 -- | 'Packet_Bundle' of 'bundle'.
@@ -116,17 +116,16 @@ packet_has_address x =
 
 -- * Pretty printing
 
--- | Pretty printer for 'Message'.
+{- | Pretty printer for 'Message'.
+
+> messagePP Nothing (Message "/m" [int32 0,float 1.0,string "s",midi (1,2,3,4),blob [1,2,3]])
+-}
 messagePP :: FP_Precision -> Message -> String
-messagePP p (Message a d) =
-    let d' = map (datumPP p) d
-    in unwords ("#message" : a : d')
+messagePP p (Message a d) = let d' = map (datumPP p) d in unwords (a : d')
 
 -- | Pretty printer for 'Bundle'.
 bundlePP :: FP_Precision -> Bundle -> String
-bundlePP p (Bundle t m) =
-    let m' = intersperse ";" (map (messagePP p) m)
-    in unwords ("#bundle" : timePP p t : m')
+bundlePP p (Bundle t m) = let m' = intersperse ";" (map (messagePP p) m) in unwords (timePP p t : m')
 
 -- | Pretty printer for 'Packet'.
 packetPP :: FP_Precision -> Packet -> String
