@@ -9,25 +9,26 @@ import qualified System.IO as IO {- base -}
 import qualified Sound.OSC.Coding.Decode.Binary as Binary {- hosc -}
 import qualified Sound.OSC.Coding.Encode.Builder as Builder {- hosc -}
 import qualified Sound.OSC.Coding.Byte as Byte {- hosc -}
+import qualified Sound.OSC.Coding.Convert as Convert {- hosc -}
 import qualified Sound.OSC.Packet as Packet {- hosc -}
 import qualified Sound.OSC.Transport.FD as FD {- hosc -}
 
 -- | The TCP transport handle data type.
-data TCP = TCP {tcpHandle :: IO.Handle}
+newtype TCP = TCP {tcpHandle :: IO.Handle}
 
 -- | Send packet over TCP.
 tcp_send_packet :: TCP -> Packet.Packet -> IO ()
 tcp_send_packet (TCP fd) p = do
   let b = Builder.encodePacket p
-      n = fromIntegral (B.length b)
-  B.hPut fd (B.append (Byte.encode_u32 n) b)
+      n = Convert.int64_to_word32 (B.length b)
+  B.hPut fd (B.append (Byte.encode_word32 n) b)
   IO.hFlush fd
 
 -- | Receive packet over TCP.
 tcp_recv_packet :: TCP -> IO Packet.Packet
 tcp_recv_packet (TCP fd) = do
   b0 <- B.hGet fd 4
-  b1 <- B.hGet fd (fromIntegral (Byte.decode_u32 b0))
+  b1 <- B.hGet fd (Convert.word32_to_int (Byte.decode_word32 b0))
   return (Binary.decodePacket b1)
 
 -- | Close TCP.
@@ -48,7 +49,8 @@ with_tcp u = Exception.bracket u tcp_close
 tcp_socket :: (N.Socket -> N.SockAddr -> IO ()) -> Maybe String -> Int -> IO N.Socket
 tcp_socket f host port = do
   fd <- N.socket N.AF_INET N.Stream 0
-  i:_ <- N.getAddrInfo Nothing host (Just (show port))
+  let hints = N.defaultHints {N.addrFamily = N.AF_INET} -- localhost=ipv4
+  i:_ <- N.getAddrInfo (Just hints) host (Just (show port))
   let sa = N.addrAddress i
   _ <- f fd sa
   return fd
